# Contributing to CV-CUDA

**As of release v0.2.0-alpha, CV-CUDA is not accepting outside contribution.**

Contributions to CV-CUDA fall into the following categories:

1. To report a bug, request a new feature, or report a problem with documentation,
   please file an [issue](https://github.com/CVCUDA/CV-CUDA/issues/new/choose)
   describing the problem or new feature in detail. The CV-CUDA team evaluates
   and triages issues, and schedules them for a release. If you believe the issue
   needs priority attention, please comment on the issue to notify the team.
1. To propose a new feature, please file a new feature request
   [issue](https://github.com/CVCUDA/CV-CUDA/issues/new/choose). Describe the
   intended feature and discuss the design and implementation with the team and
   community. NOTE: Currently, as of release v0.2.0-alpha, CV-CUDA is not accepting
   outside contribution.
1. To ask a general question, please sumbit a question
   [issue](https://github.com/CVCUDA/CV-CUDA/issues/new/choose). If you need
   more context on a particular issue, please ask in a comment.

As contributors and maintainers to this project, you are expected to abide by
CV-CUDA's contributor code of conduct. More information can be found at:
[Contributor Code of Conduct](https://github.com/CVCUDA/CV-CUDA/tree/main/CODE_OF_CONDUCT.md).
